==> org.robokind.api.speech-0.8.2-sources.jar: org/robokind/api/speech/osgi/Activator.java <==
/*
 * Copyright 2012 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.speech.osgi;

import java.util.logging.Level;
import java.util.logging.Logger;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.robokind.api.common.services.ServiceUtils;
import org.robokind.api.speech.viseme.config.VisemeBindingManagerServiceFactory;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class Activator implements BundleActivator {
    private final static Logger theLogger = 
            Logger.getLogger(Activator.class.getName());

    @Override
    public void start(BundleContext context) throws Exception {
        theLogger.log(Level.INFO, "org.robokind.api.speech Activation Begin.");
        ServiceRegistration fact = ServiceUtils.registerServiceFactory(
                context, new VisemeBindingManagerServiceFactory(), null);
        theLogger.log(Level.INFO, 
                "org.robokind.api.speech Activation Complete.");
    }
    
    public void stop(BundleContext context) throws Exception {
        //TODO add deactivation code here
    }
}

==> org.robokind.api.speech-0.8.9.1-sources.jar: org/robokind/api/speech/osgi/Activator.java <==
/*
 * Copyright 2012 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.speech.osgi;

import java.util.logging.Level;
import java.util.logging.Logger;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.robokind.api.common.services.ServiceUtils;
import org.robokind.api.speech.viseme.config.VisemeBindingManagerFactory;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class Activator implements BundleActivator {
    private final static Logger theLogger = 
            Logger.getLogger(Activator.class.getName());

    @Override
    public void start(BundleContext context) throws Exception {
        theLogger.log(Level.INFO, "org.robokind.api.speech Activation Begin.");
        ServiceUtils.registerFactory(
                context, new VisemeBindingManagerFactory(), null);
        theLogger.log(Level.INFO, 
                "org.robokind.api.speech Activation Complete.");
    }
    
    public void stop(BundleContext context) throws Exception {
        //TODO add deactivation code here
    }
}
